@@ -98,7 +98,7 @@ Vue.component('edit-field', {
     computed: {
         html: function () {
             return this.$data._value
-                ? marked(this.$data._value, { sanitize: true })
+                ? marked(this.$data._value, { sanitize: false })
                 : '';
         }
     },
@@ -628,7 +628,7 @@ var app = new Vue({
                 else if ( prop.format == 'markdown' ) {
                     if ( prop['x-html-field'] ) {
                         copy[ prop['x-html-field'] ]
-                            = marked( copy[k], { sanitize: true });
+                            = marked( copy[k], { sanitize: false });
                     }
                 }
                 else if ( copy[k] === null ) {
